import type { BarcodeFormat } from '../barcode/BarcodeTypes';
import { ToJsonConfiguration } from '../utils/json/JsonSerializationTypes';
import type { DeepPartial } from '../utils/utils';
import { PartiallyConstructible } from '../utils/utils';
/**
Type of barcode document format used.

- `AAMVA`:
   American Association of Motor Vehicle Administrators barcode document.
- `BOARDING_PASS`:
   Boarding pass barcode document.
- `DE_MEDICAL_PLAN`:
   German medication plan barcode document.
- `MEDICAL_CERTIFICATE`:
   German medical certificate barcode document.
- `ID_CARD_PDF_417`:
   ID card barcode document.
- `SEPA`:
   SEPA barcode (aka GiroCode) document.
- `SWISS_QR`:
   Swiss QR barcode document.
- `VCARD`:
   VCard barcode document.
- `GS1`:
   GS1 barcode document.
- `HIBC`:
   Health industry barcode document.
*/
export type BarcodeDocumentFormat = 'AAMVA' | 'BOARDING_PASS' | 'DE_MEDICAL_PLAN' | 'MEDICAL_CERTIFICATE' | 'ID_CARD_PDF_417' | 'SEPA' | 'SWISS_QR' | 'VCARD' | 'GS1' | 'HIBC';
export declare const BarcodeDocumentFormatValues: BarcodeDocumentFormat[];
/**
Barcode document formats.
*/
export declare class BarcodeDocumentFormats extends PartiallyConstructible {
    /** @param source {@displayType `DeepPartial<BarcodeDocumentFormats>`} */
    constructor(source?: DeepPartial<BarcodeDocumentFormats>);
    serialize(config?: ToJsonConfiguration): DeepPartial<BarcodeDocumentFormats>;
}
export declare namespace BarcodeDocumentFormats {
    /**
      All barcode document formats.
      */
    const all: BarcodeDocumentFormat[];
    /**
      Barcode types that are used to encode documents.
      */
    const documentBarcodeFormats: {
        [key in BarcodeDocumentFormat]: BarcodeFormat[];
    };
}
