import type { CompressFormat, FileEncryptionMode, LicenseStatus } from './barcodeSDKTypes';
export interface ExtractImagesFromPdfArguments {
    /**
     * The location of the PDF file
     */
    pdfFilePath: string;
    /**
     * The quality that each extracted image should have.
     * This tweaks the compression, affecting the final image file size.
     * (100: maximum quality, 0: minimum quality)
     *
     * Default value is 90
     */
    quality?: number;
    /**
     * Integer scaling factor applied to the PDF media box frame while extracting.
     * Affects the output image quality.
     * In most cases the recommended value is 2 or higher.
     *
     * Default value is 2.
     */
    scaling?: number;
    /**
     * Compress format used for extracted images. Android only.
     *
     * Default value is JPEG.
     */
    compressFormat?: CompressFormat;
}
export interface ScanbotBarcodeSdkConfiguration {
    /** Optional boolean flag to enable logging. See the "Logging" section below. */
    loggingEnabled?: boolean;
    /** Optional boolean flag that enables Scanbot SDK Core native logging (default is false, Android only). */
    enableNativeLogging?: boolean;
    /** Your license key for the Scanbot SDK. See the "License Key" section below. */
    licenseKey?: string;
    /** Optional directory as file URI to override the default storage base directory of the Scanbot SDK. Refer to the section "Storage" for more details. */
    storageBaseDirectory?: string;
    /** Optional file encryption mode, 'AES128' or 'AES256'. */
    fileEncryptionMode?: FileEncryptionMode;
    /** Optional file encryption password. Refer to the section "Storage Encryption" for more details. */
    fileEncryptionPassword?: string;
    /** If set to `true`, Camera X will be used for the RTU-UI components (Android only). Default is `true`. */
    useCameraX?: boolean;
    /** If set to `true`, GPU Acceleration will be enabled for Barcode Scanner, Document Scanner and Generic Document Recognizer (Android only). Default is `true`. */
    allowGpuAcceleration?: boolean;
    /** Enables/disables XNNPACK acceleration for TensorFlow ML models, which provides highly optimized implementations of floating-point neural network operators (Android only) */
    allowXnnpackAcceleration?: boolean;
}
export interface LicenseInfoResult {
    /** True if the license is valid, false otherwise */
    isLicenseValid: boolean;
    /** The license status */
    licenseStatus: LicenseStatus;
    /** Detailed license status message for development and debug purposes */
    licenseStatusMessage?: string;
    /** The license expiration date in milliseconds */
    licenseExpirationDate?: number;
}
