import { BarcodeScannerResult, type BarcodeScannerConfiguration } from './barcode/BarcodeScannerTypes';
import type { ExtractImagesFromPdfArguments, LicenseInfoResult, ResultWrapper, ScanbotBarcodeSdkConfiguration } from './base';
import type { BarcodeScannerScreenConfiguration } from './ui_v2/index';
import { BarcodeScannerUiResult } from './ui_v2/index';
export declare const ScanbotBarcodeSDK: {
    /**
     * Initialize the Scanbot Barcode Scanner SDK with the preferred configuration.
     *
     * @param {ScanbotBarcodeSdkConfiguration} config
     * @returns {Promise<LicenseInfoResult>}
     */
    initializeSdk(config: ScanbotBarcodeSdkConfiguration): Promise<LicenseInfoResult>;
    /**
     * Provides complete information about the current license status.
     *
     * @returns {Promise<LicenseInfoResult>}
     */
    getLicenseInfo(): Promise<LicenseInfoResult>;
    /**
     * Remove all files generated by this plugin.
     *
     * @returns {Promise<string>}
     */
    cleanup(): Promise<string>;
    /**
     * Opens the Ready-To-Use UI screen for scanning barcodes with the desired configuration.
     *
     * @param {BarcodeScannerScreenConfiguration} config
     * @returns {Promise<ResultWrapper<BarcodeScannerUiResult>>}
     */
    startBarcodeScanner(config: BarcodeScannerScreenConfiguration): Promise<ResultWrapper<BarcodeScannerUiResult>>;
    /**
     * Detect barcodes on the image represented by the file URL. The image file URL is part of the input arguments.
     *
     * @param {{imageFileUri: string, configuration: BarcodeScannerConfiguration}} params
     * @returns {Promise<BarcodeScannerResult>}
     */
    detectBarcodesOnImage(params: {
        imageFileUri: string;
        configuration: BarcodeScannerConfiguration;
    }): Promise<BarcodeScannerResult>;
    /**
     * Extract images from a PDF represented by the file URL. The PDF file URL is part of the input parameters.
     *
     * @param {ExtractImagesFromPdfArguments} params
     * @returns {Promise<string[]>}
     */
    extractImagesFromPDF(params: ExtractImagesFromPdfArguments): Promise<string[]>;
    /**
     * Returns the Base 64 encoded representation of the image data.
     */
    getImageData(params: {
        imageFileUri: string;
    }): Promise<string>;
};
export * from './barcode/index';
export * from './base/index';
export * from './documents/index';
export * from './imageRef/index';
export * from './ui_v2/index';
export * from './utils/index';
