import type { BarcodeItemMapper } from '../../ui_v2/barcode/BarcodeItemMapper';
import { ButtonConfiguration, StyledText } from '../../ui_v2/common/Common';
import type { DeepPartial } from '../../utils/utils';
import { PartiallyConstructible } from '../../utils/utils';
/**
Configuration of the mapper's error dialog.
*/
export declare class BarcodeItemErrorState extends PartiallyConstructible {
    /**
      Title displayed above the error message.
      */
    title: StyledText;
    /**
      Error message.
      */
    subtitle: StyledText;
    /**
      Configuration of the retry button.
      */
    retryButton: ButtonConfiguration;
    /**
      Configuration of the cancel button.
      */
    cancelButton: ButtonConfiguration;
    /** @param source {@displayType `DeepPartial<BarcodeItemErrorState>`} */
    constructor(source?: DeepPartial<BarcodeItemErrorState>);
}
/**
Format of the mapped barcode data.
*/
export declare class BarcodeMappedData extends PartiallyConstructible {
    /**
      Title of the barcode.
      */
    title: string;
    /**
      Subtitle of the barcode.
      */
    subtitle: string;
    /**
      Image of the barcode.
      */
    barcodeImage: string;
    /** @param source {@displayType `DeepPartial<BarcodeMappedData>`} */
    constructor(source?: DeepPartial<BarcodeMappedData>);
}
export declare namespace BarcodeMappedData {
    /**
      Use this key to display the original barcode image.
      
      Default is "BARCODE_IMAGE"
      */
    const BARCODE_IMAGE_KEY = "BARCODE_IMAGE";
}
/**
Configuration of the barcode data mapping.
*/
export declare class BarcodeInfoMapping extends PartiallyConstructible {
    /**
      Callback to map the barcode data to the data of the corresponding product.
      */
    barcodeItemMapper: BarcodeItemMapper | null;
    /**
      Background color of the barcode info dialog.
      
      Default is "?sbColorSurface"
      */
    sheetColor: string;
    /**
      Color of the divider and separator lines in the barcode info dialog.
      
      Default is "?sbColorOutline"
      */
    dividerColor: string;
    /**
      Background color of the overlay surrounding the barcode mapping error dialog.
      
      Default is "?sbColorModalOverlay"
      */
    modalOverlayColor: string;
    /**
      Text being displayed while a barcode is being mapped.
      */
    loadingMessage: StyledText;
    /**
      Configuration of the error state displayed when processing a barcode fails.
      */
    errorState: BarcodeItemErrorState;
    /** @param source {@displayType `DeepPartial<BarcodeInfoMapping>`} */
    constructor(source?: DeepPartial<BarcodeInfoMapping>);
}
