import { CommonBarcodeScannerConfiguration } from '../../ui_v2/barcode/BarcodeScannerConfiguration';
import { BarcodeTextLocalization } from '../../ui_v2/barcode/BarcodeTextLocalization';
import { BarcodeUseCase } from '../../ui_v2/barcode/BarcodeUseCase';
import { ActionBarConfiguration } from '../../ui_v2/common/ActionBarConfiguration';
import { CameraConfiguration } from '../../ui_v2/common/CameraConfiguration';
import { CameraPermissionScreen } from '../../ui_v2/common/CameraPermission';
import { Palette, Sound, Timeouts, Vibration } from '../../ui_v2/common/Common';
import { TopBarConfiguration } from '../../ui_v2/common/TopBarConfiguration';
import { UserGuidanceConfiguration } from '../../ui_v2/common/UserGuidanceConfiguration';
import { ViewFinderConfiguration } from '../../ui_v2/common/ViewFinderConfiguration';
import type { DeepPartial } from '../../utils/utils';
import { PartiallyConstructible } from '../../utils/utils';
/**
Configuration of the barcode scanner screen.
*/
export declare class BarcodeScannerScreenConfiguration extends PartiallyConstructible {
    /**
      Version number of the configuration object.
      
      Default is "1.0"
      */
    readonly version: string;
    /**
      The configuration object should be applied for this screen.
      
      Default is "BarcodeScanner"
      */
    readonly screen: string;
    /**
      Define the screen's base color values from which other colors are derived.
      */
    palette: Palette;
    /**
      Configuration of the all strings for barcode scanner.
      */
    localization: BarcodeTextLocalization;
    /**
      Color of the screen's background.
      
      Default is "?sbColorSurfaceLow"
      */
    backgroundColor: string;
    /**
      Configuration of the top bar.
      */
    topBar: TopBarConfiguration;
    /**
      Configuration of the action bar.
      */
    actionBar: ActionBarConfiguration;
    /**
      Configuration of the view finder.
      */
    viewFinder: ViewFinderConfiguration;
    /**
      Configuration of the text hint guiding users to move the view finder over a barcode.
      */
    userGuidance: UserGuidanceConfiguration;
    /**
      Configuration of the dialog for requesting camera permissions.
      */
    cameraPermission: CameraPermissionScreen;
    /**
      Configuration of the camera behavior.
      */
    cameraConfiguration: CameraConfiguration;
    /**
      Configuration of the scanning behavior.
      */
    scannerConfiguration: CommonBarcodeScannerConfiguration;
    /**
      Configuration of the barcode scanner screen's behavior.
      */
    useCase: BarcodeUseCase;
    /**
      Configuration of the scan confirmation sound.
      */
    sound: Sound;
    /**
      Configuration of the scan scan confirmation vibration.
      */
    vibration: Vibration;
    /**
      Configuration of timeouts.
      */
    timeouts: Timeouts;
    /**
      If enabled, the screen will not turn off while the barcode scanner is active. (Android only).
      
      Default is true
      */
    keepScreenOn: boolean;
    /** @param source {@displayType `DeepPartial<BarcodeScannerScreenConfiguration>`} */
    constructor(source?: DeepPartial<BarcodeScannerScreenConfiguration>);
}
