import { ArOverlayGeneralConfiguration } from '../../ui_v2/barcode/ArTrackingOverlayConfiguration';
import { BarcodeInfoMapping } from '../../ui_v2/barcode/BarcodeInfoMapping';
import { ButtonConfiguration, StyledText } from '../../ui_v2/common/Common';
import type { DeepPartial } from '../../utils/utils';
import { PartiallyConstructible } from '../../utils/utils';
/**
Configuration of the single barcode scanning mode.
*/
export declare class SingleScanningMode extends PartiallyConstructible {
    readonly _type: 'SingleScanningMode';
    /**
      If enabled, the confirmation sheet will be shown after the barcode has been scanned.
      
      Default is false
      */
    confirmationSheetEnabled: boolean;
    /**
      If enabled, the barcode image will be shown on the confirmation sheet.
      
      Default is true
      */
    barcodeImageVisible: boolean;
    /**
      Color of the confirmation sheet's background.
      
      Default is "?sbColorSurface"
      */
    sheetColor: string;
    /**
      Color of the divider and separator lines in the confirmation sheet.
      
      Default is "?sbColorOutline"
      */
    dividerColor: string;
    /**
      Background color of the overlay surrounding the confirmation sheet.
      
      Default is "?sbColorModalOverlay"
      */
    modalOverlayColor: string;
    /**
      Appearance of the barcode title (the barcode's value) on the confirmation sheet.
      */
    barcodeTitle: StyledText;
    /**
      Appearance of the barcode subtitle (the barcode's symbology) on the confirmation sheet.
      */
    barcodeSubtitle: StyledText;
    /**
      Appearance of the confirm button on the confirmation sheet.
      */
    submitButton: ButtonConfiguration;
    /**
      Appearance of the cancel button on the confirmation sheet.
      */
    cancelButton: ButtonConfiguration;
    /**
      Appearance of the barcode info mapping.
      */
    barcodeInfoMapping: BarcodeInfoMapping;
    /**
      Configuration of the AR overlay.
      */
    arOverlay: ArOverlayGeneralConfiguration;
    /** @param source {@displayType `DeepPartial<SingleScanningMode>`} */
    constructor(source?: DeepPartial<SingleScanningMode>);
}
