import type { DeepPartial } from '../../utils/utils';
import { PartiallyConstructible } from '../../utils/utils';
/**
Configuration used to serialize an object to json.
*/
export declare class ToJsonConfiguration extends PartiallyConstructible {
    /**
      Serialize images in the object to json. If false, then fields that contain images are not serialized.
      
      Default is true
      */
    readonly serializeImages: boolean;
    /**
      image serialization mode.
      
      Default is REFERENCE
      */
    readonly imageSerializationMode: ImageSerializationMode;
    /** @param source {@displayType `DeepPartial<ToJsonConfiguration>`} */
    constructor(source?: DeepPartial<ToJsonConfiguration>);
    serialize(config?: ToJsonConfiguration): DeepPartial<ToJsonConfiguration>;
}
/**
Image serialization mode. Applicable only when serializeImages is true.

- `REFERENCE`:
   Images are serialized as references to native resources.
- `BUFFER`:
   Images are serialized as base64 encoded buffers.
*/
export type ImageSerializationMode = 'REFERENCE' | 'BUFFER';
export declare const ImageSerializationModeValues: ImageSerializationMode[];
